==> jc-1.4.0.tar.gz: java/awt/MediaTracker__24MediaEntry.h <==
// class java.awt.MediaTracker$MediaEntry

// class file dependencies
// @dep_class 687235eeaf181287 java_awt_MediaTracker__24MediaEntry
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_MediaTracker__24MediaEntry_H_
#define _JC_java_awt_MediaTracker__24MediaEntry_H_

// Forward structure declarations
struct _jc_java_awt_Image$object;
struct _jc_java_awt_MediaTracker$object;
struct _jc_java_awt_MediaTracker__24MediaEntry$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$sub_refs	_jc_java_awt_MediaTracker__24MediaEntry$sub_refs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs	_jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$refs	_jc_java_awt_MediaTracker__24MediaEntry$refs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$nonrefs	_jc_java_awt_MediaTracker__24MediaEntry$nonrefs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$object	_jc_java_awt_MediaTracker__24MediaEntry$object;

typedef const struct _jc_java_awt_MediaTracker__24MediaEntry$vmethods	_jc_java_awt_MediaTracker__24MediaEntry$vmethods;
typedef const struct _jc_java_awt_MediaTracker__24MediaEntry$vtable	_jc_java_awt_MediaTracker__24MediaEntry$vtable;
typedef const struct _jc_java_awt_MediaTracker__24MediaEntry$vtype	_jc_java_awt_MediaTracker__24MediaEntry$vtype;

// Constructors
extern void _jc_java_awt_MediaTracker__24MediaEntry$method$_init$cc24514af0436bcf(_jc_env *, struct _jc_java_awt_MediaTracker__24MediaEntry$object *, struct _jc_java_awt_MediaTracker$object *);

// Virtual methods
extern jboolean _jc_java_awt_MediaTracker__24MediaEntry$method$imageUpdate$6f60896c29179de4(_jc_env *, struct _jc_java_awt_MediaTracker__24MediaEntry$object *, struct _jc_java_awt_Image$object *, jint, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_MediaTracker__24MediaEntry$method_info$imageUpdate$6f60896c29179de4;

// Virtual methods structure
struct _jc_java_awt_MediaTracker__24MediaEntry$vmethods {
	jboolean	(*imageUpdate$6f60896c29179de4)(_jc_env *, struct _jc_java_awt_MediaTracker__24MediaEntry$object *, struct _jc_java_awt_Image$object *, jint, jint, jint, jint, jint);
};

// Vtable
struct _jc_java_awt_MediaTracker__24MediaEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_MediaTracker__24MediaEntry$vmethods	java_awt_MediaTracker__24MediaEntry;
};

// Vtype
struct _jc_java_awt_MediaTracker__24MediaEntry$vtype {
	_jc_type			type;
	_jc_java_awt_MediaTracker__24MediaEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_MediaTracker__24MediaEntry$sub_refs {
	struct _jc_java_awt_Image$object	*image;
	struct _jc_java_awt_MediaTracker__24MediaEntry$object	*next;
	struct _jc_java_awt_MediaTracker$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_MediaTracker__24MediaEntry$refs {
    _jc_java_awt_MediaTracker__24MediaEntry$sub_refs	java_awt_MediaTracker__24MediaEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs {
	jint	id;
	jint	status;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_MediaTracker__24MediaEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs	java_awt_MediaTracker__24MediaEntry;
};

// Object instance structure
struct _jc_java_awt_MediaTracker__24MediaEntry$object {
	_jc_java_awt_MediaTracker__24MediaEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_MediaTracker__24MediaEntry$vtype	*vtype;
	_jc_java_awt_MediaTracker__24MediaEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_MediaTracker__24MediaEntry$vtype _jc_java_awt_MediaTracker__24MediaEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_MediaTracker__24MediaEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_MediaTracker__24MediaEntry$class_object;

#endif	/* _JC_java_awt_MediaTracker__24MediaEntry_H_ */

==> jc-1.4.6.tar.gz: java/awt/MediaTracker__24MediaEntry.h <==
// class java.awt.MediaTracker$MediaEntry

// class file dependencies
// @dep_class f84fbd51d2768caf java_awt_MediaTracker__24MediaEntry
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_MediaTracker__24MediaEntry_H_
#define _JC_java_awt_MediaTracker__24MediaEntry_H_

// Forward structure declarations
struct _jc_java_awt_Image$object;
struct _jc_java_awt_MediaTracker$object;
struct _jc_java_awt_MediaTracker__24MediaEntry$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$sub_refs	_jc_java_awt_MediaTracker__24MediaEntry$sub_refs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs	_jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$refs	_jc_java_awt_MediaTracker__24MediaEntry$refs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$nonrefs	_jc_java_awt_MediaTracker__24MediaEntry$nonrefs;
typedef struct _jc_java_awt_MediaTracker__24MediaEntry$object	_jc_java_awt_MediaTracker__24MediaEntry$object;

typedef const struct _jc_java_awt_MediaTracker__24MediaEntry$vmethods	_jc_java_awt_MediaTracker__24MediaEntry$vmethods;
typedef const struct _jc_java_awt_MediaTracker__24MediaEntry$vtable	_jc_java_awt_MediaTracker__24MediaEntry$vtable;
typedef const struct _jc_java_awt_MediaTracker__24MediaEntry$vtype	_jc_java_awt_MediaTracker__24MediaEntry$vtype;

// Constructors
extern void _jc_java_awt_MediaTracker__24MediaEntry$method$_init$cc24514af0436bcf(_jc_env *, struct _jc_java_awt_MediaTracker__24MediaEntry$object *, struct _jc_java_awt_MediaTracker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_MediaTracker__24MediaEntry$method$imageUpdate$6f60896c29179de4(_jc_env *, struct _jc_java_awt_MediaTracker__24MediaEntry$object *, struct _jc_java_awt_Image$object *, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_MediaTracker__24MediaEntry$method_info$imageUpdate$6f60896c29179de4;

// Virtual methods structure
struct _jc_java_awt_MediaTracker__24MediaEntry$vmethods {
	jboolean	(*imageUpdate$6f60896c29179de4)(_jc_env *, struct _jc_java_awt_MediaTracker__24MediaEntry$object *, struct _jc_java_awt_Image$object *, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_MediaTracker__24MediaEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_MediaTracker__24MediaEntry$vmethods	java_awt_MediaTracker__24MediaEntry;
};

// Vtype
struct _jc_java_awt_MediaTracker__24MediaEntry$vtype {
	_jc_type			type;
	_jc_java_awt_MediaTracker__24MediaEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_MediaTracker__24MediaEntry$sub_refs {
	struct _jc_java_awt_Image$object	*image;
	struct _jc_java_awt_MediaTracker__24MediaEntry$object	*next;
	struct _jc_java_awt_MediaTracker$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_MediaTracker__24MediaEntry$refs {
    _jc_java_awt_MediaTracker__24MediaEntry$sub_refs	java_awt_MediaTracker__24MediaEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs {
	jint	id;
	jint	status;
	jint	width;
	jint	height;
};

// Non-reference instance fields (object)
struct _jc_java_awt_MediaTracker__24MediaEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_MediaTracker__24MediaEntry$sub_nonrefs	java_awt_MediaTracker__24MediaEntry;
};

// Object instance structure
struct _jc_java_awt_MediaTracker__24MediaEntry$object {
	_jc_java_awt_MediaTracker__24MediaEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_MediaTracker__24MediaEntry$vtype	*vtype;
	_jc_java_awt_MediaTracker__24MediaEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_MediaTracker__24MediaEntry$vtype _jc_java_awt_MediaTracker__24MediaEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_MediaTracker__24MediaEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_MediaTracker__24MediaEntry$class_object;

#endif	/* _JC_java_awt_MediaTracker__24MediaEntry_H_ */
